# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/limit_order/v1/limit_order.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/limit_order/v1/limit_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/trading/limit_order/v1/limit_order.proto\x12 meshtrade.trading.limit_order.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1emeshtrade/type/v1/amount.proto\"\x9d\x08\n\nLimitOrder\x12\xc8\x01\n\x04name\x18\x01 \x01(\tB\xb3\x01\xbaH\xaf\x01\xba\x01\xab\x01\n\x14name.format.optional\x12\x39name must be empty or in the format limit_orders/{ULIDv2}\x1aXsize(this) == 0 || this.matches(\'^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12V\n\x06owners\x18\x03 \x03(\tB>\xbaH;\x92\x01\x38\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!R\x06owners\x12X\n\x07\x61\x63\x63ount\x18\x05 \x01(\tB>\xbaH;r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01#\xc8\x01\x01R\x07\x61\x63\x63ount\x12\x37\n\x12\x65xternal_reference\x18\x06 \x01(\tB\x08\xbaH\x05r\x03\x18\xc8\x01R\x11\x65xternalReference\x12P\n\x04side\x18\x07 \x01(\x0e\x32\x30.meshtrade.trading.limit_order.v1.LimitOrderSideB\n\xbaH\x07\x82\x01\x04\x10\x01 \x00R\x04side\x12\x42\n\x0blimit_price\x18\x08 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountB\x06\xbaH\x03\xc8\x01\x01R\nlimitPrice\x12=\n\x08quantity\x18\t \x01(\x0b\x32\x19.meshtrade.type.v1.AmountB\x06\xbaH\x03\xc8\x01\x01R\x08quantity\x12\x38\n\nfill_price\x18\n \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\tfillPrice\x12\x42\n\x0f\x66illed_quantity\x18\x0b \x01(\x0b\x32\x19.meshtrade.type.v1.AmountR\x0e\x66illedQuantity\x12G\n\x05state\x18\x0c \x01(\x0e\x32\x31.meshtrade.trading.limit_order.v1.LimitOrderStateR\x05state\x12\x16\n\x06number\x18\r \x01(\tR\x06number\x12=\n\x0csubmitted_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bsubmittedAtJ\x04\x08\x04\x10\x05R\x0c\x64isplay_name*g\n\x0eLimitOrderSide\x12 \n\x1cLIMIT_ORDER_SIDE_UNSPECIFIED\x10\x00\x12\x18\n\x14LIMIT_ORDER_SIDE_BUY\x10\x01\x12\x19\n\x15LIMIT_ORDER_SIDE_SELL\x10\x02*\xc4\x02\n\x0fLimitOrderState\x12!\n\x1dLIMIT_ORDER_STATE_UNSPECIFIED\x10\x00\x12,\n(LIMIT_ORDER_STATE_SUBMISSION_IN_PROGRESS\x10\x01\x12\'\n#LIMIT_ORDER_STATE_SUBMISSION_FAILED\x10\x02\x12\x1a\n\x16LIMIT_ORDER_STATE_OPEN\x10\x03\x12*\n&LIMIT_ORDER_STATE_COMPLETE_IN_PROGRESS\x10\x04\x12\x1e\n\x1aLIMIT_ORDER_STATE_COMPLETE\x10\x05\x12.\n*LIMIT_ORDER_STATE_CANCELLATION_IN_PROGRESS\x10\x06\x12\x1f\n\x1bLIMIT_ORDER_STATE_CANCELLED\x10\x07\x42l\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.limit_order.v1.limit_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'co.meshtrade.api.trading.limit_order.v1ZAgithub.com/meshtrade/api/go/trading/limit_order/v1;limit_order_v1'
  _globals['_LIMITORDER'].fields_by_name['name']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['name']._serialized_options = b'\272H\257\001\272\001\253\001\n\024name.format.optional\0229name must be empty or in the format limit_orders/{ULIDv2}\032Xsize(this) == 0 || this.matches(\'^limit_orders/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_LIMITORDER'].fields_by_name['owner']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_LIMITORDER'].fields_by_name['owners']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['owners']._serialized_options = b'\272H;\222\0018\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!'
  _globals['_LIMITORDER'].fields_by_name['account']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['account']._serialized_options = b'\272H;r621^accounts/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001#\310\001\001'
  _globals['_LIMITORDER'].fields_by_name['external_reference']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['external_reference']._serialized_options = b'\272H\005r\003\030\310\001'
  _globals['_LIMITORDER'].fields_by_name['side']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['side']._serialized_options = b'\272H\007\202\001\004\020\001 \000'
  _globals['_LIMITORDER'].fields_by_name['limit_price']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['limit_price']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LIMITORDER'].fields_by_name['quantity']._loaded_options = None
  _globals['_LIMITORDER'].fields_by_name['quantity']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LIMITORDERSIDE']._serialized_start=1238
  _globals['_LIMITORDERSIDE']._serialized_end=1341
  _globals['_LIMITORDERSTATE']._serialized_start=1344
  _globals['_LIMITORDERSTATE']._serialized_end=1668
  _globals['_LIMITORDER']._serialized_start=183
  _globals['_LIMITORDER']._serialized_end=1236
# @@protoc_insertion_point(module_scope)
