# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/tax_residency.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/tax_residency.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2meshtrade/compliance/client/v1/tax_residency.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\"\xec\x01\n\x0cTaxResidency\x12\xc0\x01\n\x0c\x63ountry_code\x18\x01 \x01(\tB\x9c\x01\xbaH\x98\x01\xba\x01\x94\x01\n\x1c\x63ountry_code.format.optional\x12\x45\x63ountry_code must be empty or a valid ISO 3166-1 alpha-2 country code\x1a-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')R\x0b\x63ountryCode\x12\x19\n\x03tin\x18\x02 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x03tinBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.tax_residency_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_TAXRESIDENCY'].fields_by_name['country_code']._loaded_options = None
  _globals['_TAXRESIDENCY'].fields_by_name['country_code']._serialized_options = b'\272H\230\001\272\001\224\001\n\034country_code.format.optional\022Ecountry_code must be empty or a valid ISO 3166-1 alpha-2 country code\032-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')'
  _globals['_TAXRESIDENCY'].fields_by_name['tin']._loaded_options = None
  _globals['_TAXRESIDENCY'].fields_by_name['tin']._serialized_options = b'\272H\004r\002\030d'
  _globals['_TAXRESIDENCY']._serialized_start=116
  _globals['_TAXRESIDENCY']._serialized_end=352
# @@protoc_insertion_point(module_scope)
