# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/testing/ledger/token_tap/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/testing/ledger/token_tap/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.method_options.v1 import method_options_pb2 as meshtrade_dot_option_dot_method__options_dot_v1_dot_method__options__pb2
from meshtrade.testing.ledger.token_tap.v1 import option_pb2 as meshtrade_dot_testing_dot_ledger_dot_token__tap_dot_v1_dot_option__pb2
from meshtrade.type.v1 import amount_pb2 as meshtrade_dot_type_dot_v1_dot_amount__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/testing/ledger/token_tap/v1/service.proto\x12%meshtrade.testing.ledger.token_tap.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x37meshtrade/option/method_options/v1/method_options.proto\x1a\x32meshtrade/testing/ledger/token_tap/v1/option.proto\x1a\x1emeshtrade/type/v1/amount.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\x1c\n\x1aInitialiseTokenTapsRequest\"\x1d\n\x1bInitialiseTokenTapsResponse\"\x16\n\x14ListTokenTapsRequest\"I\n\x15ListTokenTapsResponse\x12\x30\n\x06tokens\x18\x01 \x03(\x0b\x32\x18.meshtrade.type.v1.TokenR\x06tokens\"\xc2\x01\n\x10MintTokenRequest\x12\x39\n\x06\x61mount\x18\x01 \x01(\x0b\x32\x19.meshtrade.type.v1.AmountB\x06\xbaH\x03\xc8\x01\x01R\x06\x61mount\x12 \n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x61\x64\x64ress\x12Q\n\x07options\x18\x03 \x01(\x0b\x32\x37.meshtrade.testing.ledger.token_tap.v1.MintTokenOptionsR\x07options\"\x13\n\x11MintTokenResponse2\xdc\x03\n\x0fTokenTapService\x12\xa6\x01\n\x13InitialiseTokenTaps\x12\x41.meshtrade.testing.ledger.token_tap.v1.InitialiseTokenTapsRequest\x1a\x42.meshtrade.testing.ledger.token_tap.v1.InitialiseTokenTapsResponse\"\x08\xb2\xb5\x18\x04\x08\x02\x10\x01\x12\x94\x01\n\rListTokenTaps\x12;.meshtrade.testing.ledger.token_tap.v1.ListTokenTapsRequest\x1a<.meshtrade.testing.ledger.token_tap.v1.ListTokenTapsResponse\"\x08\xb2\xb5\x18\x04\x08\x01\x10\x01\x12\x88\x01\n\tMintToken\x12\x37.meshtrade.testing.ledger.token_tap.v1.MintTokenRequest\x1a\x38.meshtrade.testing.ledger.token_tap.v1.MintTokenResponse\"\x08\xb2\xb5\x18\x04\x08\x02\x10\x01\x42t\n,co.meshtrade.api.testing.ledger.token_tap.v1ZDgithub.com/meshtrade/api/go/testing/ledger/token_tap/v1;token_tap_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.testing.ledger.token_tap.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,co.meshtrade.api.testing.ledger.token_tap.v1ZDgithub.com/meshtrade/api/go/testing/ledger/token_tap/v1;token_tap_v1'
  _globals['_MINTTOKENREQUEST'].fields_by_name['amount']._loaded_options = None
  _globals['_MINTTOKENREQUEST'].fields_by_name['amount']._serialized_options = b'\272H\003\310\001\001'
  _globals['_MINTTOKENREQUEST'].fields_by_name['address']._loaded_options = None
  _globals['_MINTTOKENREQUEST'].fields_by_name['address']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TOKENTAPSERVICE'].methods_by_name['InitialiseTokenTaps']._loaded_options = None
  _globals['_TOKENTAPSERVICE'].methods_by_name['InitialiseTokenTaps']._serialized_options = b'\262\265\030\004\010\002\020\001'
  _globals['_TOKENTAPSERVICE'].methods_by_name['ListTokenTaps']._loaded_options = None
  _globals['_TOKENTAPSERVICE'].methods_by_name['ListTokenTaps']._serialized_options = b'\262\265\030\004\010\001\020\001'
  _globals['_TOKENTAPSERVICE'].methods_by_name['MintToken']._loaded_options = None
  _globals['_TOKENTAPSERVICE'].methods_by_name['MintToken']._serialized_options = b'\262\265\030\004\010\002\020\001'
  _globals['_INITIALISETOKENTAPSREQUEST']._serialized_start=295
  _globals['_INITIALISETOKENTAPSREQUEST']._serialized_end=323
  _globals['_INITIALISETOKENTAPSRESPONSE']._serialized_start=325
  _globals['_INITIALISETOKENTAPSRESPONSE']._serialized_end=354
  _globals['_LISTTOKENTAPSREQUEST']._serialized_start=356
  _globals['_LISTTOKENTAPSREQUEST']._serialized_end=378
  _globals['_LISTTOKENTAPSRESPONSE']._serialized_start=380
  _globals['_LISTTOKENTAPSRESPONSE']._serialized_end=453
  _globals['_MINTTOKENREQUEST']._serialized_start=456
  _globals['_MINTTOKENREQUEST']._serialized_end=650
  _globals['_MINTTOKENRESPONSE']._serialized_start=652
  _globals['_MINTTOKENRESPONSE']._serialized_end=671
  _globals['_TOKENTAPSERVICE']._serialized_start=674
  _globals['_TOKENTAPSERVICE']._serialized_end=1150
# @@protoc_insertion_point(module_scope)
