# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/user_profile/v1/user_profile.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/user_profile/v1/user_profile.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.type.v1 import token_pb2 as meshtrade_dot_type_dot_v1_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0meshtrade/iam/user_profile/v1/user_profile.proto\x12\x1dmeshtrade.iam.user_profile.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1dmeshtrade/type/v1/token.proto\"\xaf\n\n\x0bUserProfile\x12\xd2\x01\n\x04name\x18\x01 \x01(\tB\xbd\x01\xbaH\xb9\x01\xba\x01\xb5\x01\n\x14name.format.optional\x12>name must be empty or in the format iam/user_profiles/{ULIDv2}\x1a]size(this) == 0 || this.matches(\'^iam/user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')R\x04name\x12R\n\x05owner\x18\x02 \x01(\tB<\xbaH9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!\xc8\x01\x01R\x05owner\x12V\n\x06owners\x18\x03 \x03(\tB>\xbaH;\x92\x01\x38\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01!R\x06owners\x12\xdf\x02\n\x04user\x18\x04 \x01(\tB\xca\x02\xbaH\xc6\x02r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\x98\x01 \xba\x01V\n\ruser.required\x12\x35user is required and must be in format users/{ULIDv2}\x1a\x0esize(this) > 0\xba\x01\xb1\x01\n\x0buser.format\x12\x62user must be in format users/{ULIDv2} where ULIDv2 is exactly 26 uppercase alphanumeric characters\x1a>this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\xc8\x01\x01R\x04user\x12\xdb\x01\n\x06locale\x18\x05 \x01(\tB\xc2\x01\xbaH\xbe\x01\xba\x01\xba\x01\n\rlocale.format\x12Rlocale must be empty or a valid BCP 47 language tag (e.g., \'en\', \'en-US\', \'fr-FR\')\x1aUsize(this) == 0 || this.matches(\'^[a-z]{2,3}(-[A-Za-z]{4})?(-([A-Z]{2}|[0-9]{3}))?$\')R\x06locale\x12\xa5\x01\n\x13profile_picture_url\x18\x06 \x01(\tBu\xbaHr\xba\x01o\n\x1aprofile_picture_url.format\x12\x30profile_picture_url must be empty or a valid URI\x1a\x1fsize(this) == 0 || this.isUri()R\x11profilePictureUrl\x12)\n\x0c\x64isplay_name\x18\x07 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0b\x64isplayName\x12\x43\n\x10\x64isplay_currency\x18\x08 \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x0f\x64isplayCurrency\x12G\n\x12reporting_currency\x18\t \x01(\x0b\x32\x18.meshtrade.type.v1.TokenR\x11reportingCurrencyBg\n$co.meshtrade.api.iam.user_profile.v1Z?github.com/meshtrade/api/go/iam/user_profile/v1;user_profile_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.user_profile.v1.user_profile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$co.meshtrade.api.iam.user_profile.v1Z?github.com/meshtrade/api/go/iam/user_profile/v1;user_profile_v1'
  _globals['_USERPROFILE'].fields_by_name['name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['name']._serialized_options = b'\272H\271\001\272\001\265\001\n\024name.format.optional\022>name must be empty or in the format iam/user_profiles/{ULIDv2}\032]size(this) == 0 || this.matches(\'^iam/user_profiles/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')'
  _globals['_USERPROFILE'].fields_by_name['owner']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['owner']._serialized_options = b'\272H9r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!\310\001\001'
  _globals['_USERPROFILE'].fields_by_name['owners']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['owners']._serialized_options = b'\272H;\222\0018\"6r42/^groups/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001!'
  _globals['_USERPROFILE'].fields_by_name['user']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['user']._serialized_options = b'\272H\306\002r32.^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\230\001 \272\001V\n\ruser.required\0225user is required and must be in format users/{ULIDv2}\032\016size(this) > 0\272\001\261\001\n\013user.format\022buser must be in format users/{ULIDv2} where ULIDv2 is exactly 26 uppercase alphanumeric characters\032>this.matches(\'^users/[0123456789ABCDEFGHJKMNPQRSTVWXYZ]{26}$\')\310\001\001'
  _globals['_USERPROFILE'].fields_by_name['locale']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['locale']._serialized_options = b'\272H\276\001\272\001\272\001\n\rlocale.format\022Rlocale must be empty or a valid BCP 47 language tag (e.g., \'en\', \'en-US\', \'fr-FR\')\032Usize(this) == 0 || this.matches(\'^[a-z]{2,3}(-[A-Za-z]{4})?(-([A-Z]{2}|[0-9]{3}))?$\')'
  _globals['_USERPROFILE'].fields_by_name['profile_picture_url']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['profile_picture_url']._serialized_options = b'\272Hr\272\001o\n\032profile_picture_url.format\0220profile_picture_url must be empty or a valid URI\032\037size(this) == 0 || this.isUri()'
  _globals['_USERPROFILE'].fields_by_name['display_name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['display_name']._serialized_options = b'\272H\003\310\001\001'
  _globals['_USERPROFILE']._serialized_start=144
  _globals['_USERPROFILE']._serialized_end=1471
# @@protoc_insertion_point(module_scope)
