# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/method_options/v1/method_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/method_options/v1/method_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7meshtrade/option/method_options/v1/method_options.proto\x12\"meshtrade.option.method_options.v1\x1a google/protobuf/descriptor.proto\x1a meshtrade/iam/role/v1/role.proto\"\xc9\x02\n\rMethodOptions\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32..meshtrade.option.method_options.v1.MethodTypeR\x04type\x12X\n\x0c\x61\x63\x63\x65ss_level\x18\x02 \x01(\x0e\x32\x35.meshtrade.option.method_options.v1.MethodAccessLevelR\x0b\x61\x63\x63\x65ssLevel\x12\x31\n\x05roles\x18\x03 \x03(\x0e\x32\x1b.meshtrade.iam.role.v1.RoleR\x05roles\x12g\n\x13verification_status\x18\x04 \x01(\x0e\x32\x36.meshtrade.option.method_options.v1.VerificationStatusR\x12verificationStatus*V\n\nMethodType\x12\x1b\n\x17METHOD_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10METHOD_TYPE_READ\x10\x01\x12\x15\n\x11METHOD_TYPE_WRITE\x10\x02*|\n\x11MethodAccessLevel\x12#\n\x1fMETHOD_ACCESS_LEVEL_UNSPECIFIED\x10\x00\x12\x1e\n\x1aMETHOD_ACCESS_LEVEL_PUBLIC\x10\x01\x12\"\n\x1eMETHOD_ACCESS_LEVEL_AUTHORISED\x10\x02*[\n\x12VerificationStatus\x12#\n\x1fVERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12 \n\x1cVERIFICATION_STATUS_VERIFIED\x10\x01:z\n\x0emethod_options\x12\x1e.google.protobuf.MethodOptions\x18\xd6\x86\x03 \x01(\x0b\x32\x31.meshtrade.option.method_options.v1.MethodOptionsR\rmethodOptionsBs\n)co.meshtrade.api.option.method_options.v1ZFgithub.com/meshtrade/api/go/option/method_options/v1;method_options_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.method_options.v1.method_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)co.meshtrade.api.option.method_options.v1ZFgithub.com/meshtrade/api/go/option/method_options/v1;method_options_v1'
  _globals['_METHODTYPE']._serialized_start=495
  _globals['_METHODTYPE']._serialized_end=581
  _globals['_METHODACCESSLEVEL']._serialized_start=583
  _globals['_METHODACCESSLEVEL']._serialized_end=707
  _globals['_VERIFICATIONSTATUS']._serialized_start=709
  _globals['_VERIFICATIONSTATUS']._serialized_end=800
  _globals['_METHODOPTIONS']._serialized_start=164
  _globals['_METHODOPTIONS']._serialized_end=493
# @@protoc_insertion_point(module_scope)
