# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/industry_classification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/industry_classification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<meshtrade/compliance/client/v1/industry_classification.proto\x12\x1emeshtrade.compliance.client.v1\"\xdc\x02\n\x16IndustryClassification\x12\x1f\n\x0bsector_code\x18\x01 \x01(\tR\nsectorCode\x12\x1f\n\x0bsector_name\x18\x02 \x01(\tR\nsectorName\x12.\n\x13industry_group_code\x18\x03 \x01(\tR\x11industryGroupCode\x12.\n\x13industry_group_name\x18\x04 \x01(\tR\x11industryGroupName\x12#\n\rindustry_code\x18\x05 \x01(\tR\x0cindustryCode\x12#\n\rindustry_name\x18\x06 \x01(\tR\x0cindustryName\x12*\n\x11sub_industry_code\x18\x07 \x01(\tR\x0fsubIndustryCode\x12*\n\x11sub_industry_name\x18\x08 \x01(\tR\x0fsubIndustryNameBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.industry_classification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_INDUSTRYCLASSIFICATION']._serialized_start=97
  _globals['_INDUSTRYCLASSIFICATION']._serialized_end=445
# @@protoc_insertion_point(module_scope)
