# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/natural_person_connection_type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/natural_person_connection_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmeshtrade/compliance/client/v1/natural_person_connection_type.proto\x12\x1emeshtrade.compliance.client.v1*\xb4\x06\n\x1bNaturalPersonConnectionType\x12.\n*NATURAL_PERSON_CONNECTION_TYPE_UNSPECIFIED\x10\x00\x12<\n8NATURAL_PERSON_CONNECTION_TYPE_ULTIMATE_BENEFICIAL_OWNER\x10\x01\x12.\n*NATURAL_PERSON_CONNECTION_TYPE_SHAREHOLDER\x10\x02\x12+\n\'NATURAL_PERSON_CONNECTION_TYPE_DIRECTOR\x10\x03\x12\x34\n0NATURAL_PERSON_CONNECTION_TYPE_SENIOR_MANAGEMENT\x10\x04\x12\x37\n3NATURAL_PERSON_CONNECTION_TYPE_AUTHORIZED_SIGNATORY\x10\x05\x12*\n&NATURAL_PERSON_CONNECTION_TYPE_FOUNDER\x10\x06\x12)\n%NATURAL_PERSON_CONNECTION_TYPE_SPOUSE\x10\x14\x12\x33\n/NATURAL_PERSON_CONNECTION_TYPE_DOMESTIC_PARTNER\x10\x15\x12)\n%NATURAL_PERSON_CONNECTION_TYPE_PARENT\x10\x16\x12(\n$NATURAL_PERSON_CONNECTION_TYPE_CHILD\x10\x17\x12*\n&NATURAL_PERSON_CONNECTION_TYPE_SIBLING\x10\x18\x12\x33\n/NATURAL_PERSON_CONNECTION_TYPE_BUSINESS_PARTNER\x10\x1e\x12\x32\n.NATURAL_PERSON_CONNECTION_TYPE_CLOSE_ASSOCIATE\x10\x1f\x12,\n(NATURAL_PERSON_CONNECTION_TYPE_GUARANTOR\x10 \x12\x37\n3NATURAL_PERSON_CONNECTION_TYPE_BENEFICIARY_OF_TRUST\x10!Bc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.natural_person_connection_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_NATURALPERSONCONNECTIONTYPE']._serialized_start=104
  _globals['_NATURALPERSONCONNECTIONTYPE']._serialized_end=924
# @@protoc_insertion_point(module_scope)
