# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/compliance/client/v1/natural_person.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/compliance/client/v1/natural_person.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from meshtrade.compliance.client.v1 import identification_document_type_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_identification__document__type__pb2
from meshtrade.compliance.client.v1 import pep_status_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_pep__status__pb2
from meshtrade.compliance.client.v1 import source_of_income_and_wealth_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_source__of__income__and__wealth__pb2
from meshtrade.compliance.client.v1 import tax_residency_pb2 as meshtrade_dot_compliance_dot_client_dot_v1_dot_tax__residency__pb2
from meshtrade.type.v1 import address_pb2 as meshtrade_dot_type_dot_v1_dot_address__pb2
from meshtrade.type.v1 import contact_details_pb2 as meshtrade_dot_type_dot_v1_dot_contact__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3meshtrade/compliance/client/v1/natural_person.proto\x12\x1emeshtrade.compliance.client.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x16google/type/date.proto\x1a\x41meshtrade/compliance/client/v1/identification_document_type.proto\x1a/meshtrade/compliance/client/v1/pep_status.proto\x1a@meshtrade/compliance/client/v1/source_of_income_and_wealth.proto\x1a\x32meshtrade/compliance/client/v1/tax_residency.proto\x1a\x1fmeshtrade/type/v1/address.proto\x1a\'meshtrade/type/v1/contact_details.proto\"\xdf\t\n\rNaturalPerson\x12%\n\tfull_name\x18\x01 \x01(\tB\x08\xbaH\x05r\x03\x18\xff\x01R\x08\x66ullName\x12\x35\n\rdate_of_birth\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x0b\x64\x61teOfBirth\x12\xdd\x01\n\x16\x63ountry_of_citizenship\x18\x03 \x01(\tB\xa6\x01\xbaH\xa2\x01\xba\x01\x9e\x01\n\x1c\x63ountry_code.format.optional\x12Ocountry_of_citizenship must be empty or a valid ISO 3166-1 alpha-2 country code\x1a-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')R\x14\x63ountryOfCitizenship\x12<\n\x15identification_number\x18\x04 \x01(\tB\x07\xbaH\x04r\x02\x18\x64R\x14identificationNumber\x12\x86\x01\n\x1cidentification_document_type\x18\x05 \x01(\x0e\x32:.meshtrade.compliance.client.v1.IdentificationDocumentTypeB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x1aidentificationDocumentType\x12`\n#identification_document_expiry_date\x18\x06 \x01(\x0b\x32\x11.google.type.DateR identificationDocumentExpiryDate\x12\x45\n\x10physical_address\x18\x07 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\x0fphysicalAddress\x12\x41\n\x0epostal_address\x18\x08 \x01(\x0b\x32\x1a.meshtrade.type.v1.AddressR\rpostalAddress\x12R\n\npep_status\x18\t \x01(\x0e\x32).meshtrade.compliance.client.v1.PepStatusB\x08\xbaH\x05\x82\x01\x02\x10\x01R\tpepStatus\x12J\n\x0f\x63ontact_details\x18\n \x01(\x0b\x32!.meshtrade.type.v1.ContactDetailsR\x0e\x63ontactDetails\x12r\n\x11sources_of_income\x18\x0b \x03(\x0e\x32\x37.meshtrade.compliance.client.v1.SourceOfIncomeAndWealthB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x0fsourcesOfIncome\x12r\n\x11sources_of_wealth\x18\x0c \x03(\x0e\x32\x37.meshtrade.compliance.client.v1.SourceOfIncomeAndWealthB\r\xbaH\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01R\x0fsourcesOfWealth\x12U\n\x0ftax_residencies\x18\r \x03(\x0b\x32,.meshtrade.compliance.client.v1.TaxResidencyR\x0etaxResidenciesBc\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.compliance.client.v1.natural_person_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%co.meshtrade.api.compliance.client.v1Z:github.com/meshtrade/api/go/compliance/client/v1;client_v1'
  _globals['_NATURALPERSON'].fields_by_name['full_name']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['full_name']._serialized_options = b'\272H\005r\003\030\377\001'
  _globals['_NATURALPERSON'].fields_by_name['country_of_citizenship']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['country_of_citizenship']._serialized_options = b'\272H\242\001\272\001\236\001\n\034country_code.format.optional\022Ocountry_of_citizenship must be empty or a valid ISO 3166-1 alpha-2 country code\032-size(this) == 0 || this.matches(\'^[A-Z]{2}$\')'
  _globals['_NATURALPERSON'].fields_by_name['identification_number']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['identification_number']._serialized_options = b'\272H\004r\002\030d'
  _globals['_NATURALPERSON'].fields_by_name['identification_document_type']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['identification_document_type']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_NATURALPERSON'].fields_by_name['pep_status']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['pep_status']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_NATURALPERSON'].fields_by_name['sources_of_income']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['sources_of_income']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_NATURALPERSON'].fields_by_name['sources_of_wealth']._loaded_options = None
  _globals['_NATURALPERSON'].fields_by_name['sources_of_wealth']._serialized_options = b'\272H\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_NATURALPERSON']._serialized_start=449
  _globals['_NATURALPERSON']._serialized_end=1696
# @@protoc_insertion_point(module_scope)
